==> rattail_locsms-0.3.13.tar.gz: rattail_locsms-0.3.13/rattail_locsms/commands.py <==
#!/usr/bin/env python
# -*- coding: utf-8  -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2012 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
Rattail Commands
"""

import os
import re
import sys
import shutil
import zipfile

from edbob.exceptions import ConfigError

from rattail.commands import Subcommand
from rattail.files import temp_path


def get_node(path):
    from rattail_locsms.deploy import Node, get_node

    node = None
    if path:
        node = Node(path=path)
        node.read_config()
    else:
        try:
            node = get_node()
        except ConfigError:
            pass
    if not node:
        sys.stderr.write("Could not determine node path; please specify with --node-path\n")
        return None
    return node


class AdminCommand(Subcommand):
    """
    Launches the 'SMS Admin' utility.  This tool is useful for administering
    SMS in both development and production environments.
    """

    name = 'sms-admin'
    description = "Launch 'SMS Admin' utility"

    def run(self, args):
        from edbob.wx import LaunchDialog
        from rattail_locsms.wx.Admin import AdminDialog
        LaunchDialog(AdminDialog)


class BackupDataCommand(Subcommand):
    """
    Generates a ZIP file containing selected load data from a SMS instance.
    """

    name = 'sms-backup-data'
    description = "Generate ZIP file with selected SMS load data"

    def add_parser_args(self, parser):
        parser.add_argument('zip_file', metavar='ZIP_FILE',
                            help="Path to output ZIP file")
        parser.add_argument('-N', '--node-path',
                            help=r"Path to SMS instance node (e.g. C:\Storeman)")

    def run(self, args):
        node = get_node(args.node_path)
        if not node:
            return

        files = [
            'Alt_Load.sql',
            'Btl_Load.sql',
            'Cat_Load.sql',
            'Clf_Load.sql',
            'Clg_Load.sql',
            'Clk_Load.sql',
            'Cll_Load.sql',
            'Clr_Load.sql',
            'Clt_Load.sql',
            'Cost_Load.sql',
            'Dept_Load.sql',
            'ECL_Load.sql',
            'Kit_Load.sql',
            'Obj_Load.sql',
            'Pos_Load.sql',
            'Price_Load.sql',
            'Scl_Load.sql',
            'Scl_Nut_load.sql',
            'Scl_txt_Load.sql',
            'Sdp_Load.sql',
            'Vendor_Load.sql',
            ]

        temp_path = temp_path(prefix='rattail.sms.', suffix='.zip')
        zip_file = zipfile.ZipFile(temp_path, 'w')
        for fn in files:
            load_path = node.get_load_path(fn)
            zip_file.write(load_path, fn)
        zip_file.close()
        shutil.move(temp_path, args.zip_file)


class GenerateSampleCommand(Subcommand):
    """
    Generates a zipped Sample (or Option) file to an SMS install folder; called
    as ``rattail sms-gen-sample``.
    """

    name = 'sms-gen-sample'
    description = "Generate zipped SMS Sample (or Option) file"

    def add_parser_args(self, parser):
        parser.add_argument('source_dir',
                            help=r"Path to Sample source code (e.g. C:\Samples\MySample)")
        parser.add_argument('target_dir',
                            help=r"Path to Samples folder (e.g. C:\Storeman\install\Samples)")
        parser.add_argument('-t', '--fix-timestamp', action='store_true',
                            help="Set timestamp according to source control log")
        parser.add_argument('-m', '--mako-args', nargs='*', metavar='VAR=VAL',
                            help="Render *.mako files with specified Mako context vars")

    def run(self, args):
        from rattail_locsms.samples import generate_sample

        mako_arg_pattern = re.compile(r'^([A-Za-z_]+)=(.*)$')

        mako_args = {}
        if args.mako_args:
            for elem in args.mako_args:
                m = mako_arg_pattern.match(elem)
                if not m:
                    sys.stderr.write("Invalid Mako argument: %s\n" % elem)
                    return
                mako_args[m.group(1)] = eval(m.group(2))

        generate_sample(args.source_dir, args.target_dir,
                        render_mako=bool(mako_args),
                        use_source_time=args.fix_timestamp,
                        **mako_args)


class PullSampleCommand(Subcommand):
    """
    "Pulls" an SMS Sample (or Option) zip file into a source repository's
    working directory; called as ``rattail sms-pull-sample``.

    This tool will unzip the sample (or option) file and copy the individual
    files contained within it to the local working directory (which is assumed
    to be associated with a source repository).
    """

    name = 'sms-pull-sample'
    description = "Pull zipped SMS Sample (or Option) file"

    def add_parser_args(self, parser):
        parser.add_argument('sample_file',
                            help=r"Path to zipped Sample (e.g. C:\Storeman\install\Samples\MySample.zip)")
        parser.add_argument('source_dir',
                            help=r"Path to source working directory (e.g. C:\Samples\MySample)")

    def run(self, args):
        from rattail_locsms.samples import absorb_sample
        absorb_sample(args.sample_file, args.source_dir)


class RestoreDataCommand(Subcommand):
    """
    Deploys load data from a ZIP file into a SMS inbox.
    """

    name = 'sms-restore-data'
    description = "Deploy load data from ZIP file to SMS inbox"

    def add_parser_args(self, parser):
        parser.add_argument('zip_file',
                            help="Path to zipped load data file")
        parser.add_argument('-N', '--node-path',
                            help=r"Path to SMS instance node (e.g. C:\Storeman)")

    def run(self, args):
        node = get_node(args.node_path)
        if not node:
            return

        zip_file = zipfile.ZipFile(args.zip_file, 'r')
        for fn in zip_file.namelist():
            zip_file.extract(fn)
            node.deploy_to_inbox(fn)
            os.remove(fn)
        zip_file.close()

==> rattail_locsms-0.3.19.tar.gz: rattail_locsms-0.3.19/rattail_locsms/commands.py <==
# -*- coding: utf-8 -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2014 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
Rattail Commands
"""

from __future__ import unicode_literals

import os
import re
import sys
import shutil
import zipfile

from rattail.commands import Subcommand


class AdminCommand(Subcommand):
    """
    Launches the 'SMS Admin' utility.  This tool is useful for administering
    SMS in both development and production environments.
    """

    name = 'sms-admin'
    description = "Launch 'SMS Admin' utility"

    def run(self, args):
        from edbob.wx import LaunchDialog
        from rattail_locsms.wx.Admin import AdminDialog
        LaunchDialog(AdminDialog)


class GenerateSampleCommand(Subcommand):
    """
    Generates a zipped Sample (or Option) file to an SMS install folder; called
    as ``rattail sms-gen-sample``.
    """

    name = 'sms-gen-sample'
    description = "Generate zipped SMS Sample (or Option) file"

    def add_parser_args(self, parser):
        parser.add_argument('source_dir',
                            help=r"Path to Sample source code (e.g. C:\Samples\MySample)")
        parser.add_argument('target_dir',
                            help=r"Path to Samples folder (e.g. C:\Storeman\install\Samples)")
        parser.add_argument('-t', '--fix-timestamp', action='store_true',
                            help="Set timestamp according to source control log")
        parser.add_argument('-m', '--mako-args', nargs='*', metavar='VAR=VAL',
                            help="Render *.mako files with specified Mako context vars")

    def run(self, args):
        from rattail_locsms.samples import generate_sample

        mako_arg_pattern = re.compile(r'^([A-Za-z_]+)=(.*)$')

        mako_args = {}
        if args.mako_args:
            for elem in args.mako_args:
                m = mako_arg_pattern.match(elem)
                if not m:
                    sys.stderr.write("Invalid Mako argument: %s\n" % elem)
                    return
                mako_args[m.group(1)] = eval(m.group(2))

        generate_sample(self.config, args.source_dir, args.target_dir,
                        render_mako=bool(mako_args),
                        use_source_time=args.fix_timestamp,
                        **mako_args)


class PullSampleCommand(Subcommand):
    """
    "Pulls" an SMS Sample (or Option) zip file into a source repository's
    working directory; called as ``rattail sms-pull-sample``.

    This tool will unzip the sample (or option) file and copy the individual
    files contained within it to the local working directory (which is assumed
    to be associated with a source repository).
    """

    name = 'sms-pull-sample'
    description = "Pull zipped SMS Sample (or Option) file"

    def add_parser_args(self, parser):
        parser.add_argument('sample_file',
                            help=r"Path to zipped Sample (e.g. C:\Storeman\install\Samples\MySample.zip)")
        parser.add_argument('source_dir',
                            help=r"Path to source working directory (e.g. C:\Samples\MySample)")

    def run(self, args):
        from rattail_locsms.samples import absorb_sample
        absorb_sample(args.sample_file, args.source_dir)
